@@ -3,14 +3,14 @@ package TestMethodAsync;
 sub func1_async()
 {
 	my $cv = AE::cv;
-	my $w; $w = AE::timer 2, 0, sub { undef $w; $cv->send(1); };
+	my $w; $w = AE::timer 0.1, 0, sub { undef $w; $cv->send(1); };
 	return $cv;
 }
 
 sub func2_async()
 {
 	my $cv = AE::cv;
-	my $w; $w = AE::timer 2, 0, sub { undef $w; $cv->send(2); };
+	my $w; $w = AE::timer 0.1, 0, sub { undef $w; $cv->send(2); };
 	return $cv;
 }
 
